SdkFeatureFlags class

Constructors

SdkFeatureFlags({required bool realtime, required bool attachments, required bool csat, required bool pushRegistration})
const

Properties

attachments → bool
final
csat → bool
final
hashCode → int
The hash code for this object.
no setterinherited
pushRegistration → bool
final
realtime → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enabled(SdkFeature feature) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited