csatPrompt property

String csatPrompt
final

CSAT prompt shown above the composer on a resolved/closed thread until the customer rates. The faces (😔😕😐🙂😄) and the optional comment are decoupled from reopening (reopenHint).

Implementation

final String csatPrompt;