readReceiptLabel property
Accessibility-only status announced on an own message support has read. Not rendered as visible text (the tick conveys it visually).
Implementation
final String readReceiptLabel;
Accessibility-only status announced on an own message support has read. Not rendered as visible text (the tick conveys it visually).
final String readReceiptLabel;