reopenButton property
Label for the Reply button shown in place of the composer on a resolved/closed thread; tapping it reveals the composer (which reopens).
Implementation
final String reopenButton;
Label for the Reply button shown in place of the composer on a resolved/closed thread; tapping it reveals the composer (which reopens).
final String reopenButton;