yourTurn property
Inbox row chip when support has replied and the customer hasn't read it yet — the ball is in the customer's court.
Implementation
final String yourTurn;
Inbox row chip when support has replied and the customer hasn't read it yet — the ball is in the customer's court.
final String yourTurn;